#' @name PaulinoEx10.6
#' @title Hipertensão Arterial Medida Através da Sensibilidade ao Sal
#' @description Em um estudo sobre hipertensão arterial, pacientes foram
#'     avaliados quanto a sensibilidade ao sal através de um método
#'     usual e um método experimental (utiliza a fludrocortizona como
#'     agente potencializador da sensibilidade). Sob cada método, o
#'     paciente foi classificado em uma de três categorias: sensível ao
#'     sal, inconclusivo e insensível ao sal.
#' @format Um \code{data.frame} com 18 observações e 4 variáveis, em que
#'
#' \describe{
#'
#' \item{\code{estudo}}{Estudo em que os indivíduos foram avaliados (1 ou 2).}
#'
#' \item{\code{usual}}{Avaliação segundo o método usual (insensível,
#'     inconclusivo ou sensível ao sal).}
#'
#' \item{\code{exper}}{Avaliação segundo o método experimental
#'     (insensível, inconclusivo ou sensível ao sal).}
#'
#' \item{\code{freq}}{Número de pacientes avaliados.}
#'
#' }
#' @keywords TC dicotômica
#' @source PAULINO; SINGER (2006), Exercício 10.6, pág. 368.
#' @examples
#'
#' data(PaulinoEx10.6)
#'
#' str(PaulinoEx10.6)
#'
#' xt <- xtabs(freq ~ ., data = PaulinoEx10.6)
#' ftable(xt)
#'
#' library(lattice)
#'
#' barchart(xt,
#'          horizontal = FALSE,
#'          beside = FALSE,
#'          stack = FALSE,
#'          auto.key = list(space = "top", columns = 3, cex.title = 1,
#'                          rectangles = TRUE, points = FALSE,
#'                          title = "Método experimental"),
#'          xlab = "Estudo",
#'          ylab = "Frequências",
#'          strip = strip.custom(
#'              strip.names = TRUE,
#'              var.name = "método usual"))
#'
NULL